using System;

namespace Spaanjaars.Toolkit
{
  /// <summary>
  /// The RateEventArgs class is a simple EventArgs class used to provide additional data to Rating and Rated events in the <see cref="ContentRating"/> control.
  /// </summary>
  public class RateEventArgs : System.EventArgs
  {

    #region Private Variables

    private int rateValue;
    private bool hasRated;
    private bool supportsCookies = false;
    private bool cancel = false;

    #endregion

    #region Constructor(s)
    /// <summary>
    /// Initializes a new instance of the <see cref="RateEventArgs"/> class.
    /// </summary>
    /// <param name="rateValue">The rate value.</param>
    /// <param name="hasRated">if set to <c>true</c> the user has already rated.</param>
    public RateEventArgs(int rateValue, bool hasRated)
    {
      this.rateValue = rateValue;
      this.hasRated = hasRated;
    }
    #endregion

    #region Public Properties

    /// <summary>
    /// Gets or sets a value indicating whether the user agent supports cookies.
    /// </summary>
    public bool SupportsCookies
    {
      get { return supportsCookies; }
      internal set { supportsCookies = value; }
    }

    /// <summary>
    /// Gets or sets a value indicating whether the rate should be cancelled.
    /// </summary>
    /// <value><c>true</c> if the rate must be cancelled; otherwise, <c>false</c>.</value>
    public bool Cancel
    {
      get { return cancel; }
      set { cancel = value; }
    }

    /// <summary>
    /// Gets or sets a value indicating whether the user has already rated.
    /// </summary>
    /// <value><c>true</c> if the user has already rated; otherwise, <c>false</c>.</value>
    public bool HasRated
    {
      get { return this.hasRated; }
      internal set { this.hasRated = value; }
    }

    /// <summary>
    /// Gets or sets the value of the item the user has chosen.
    /// </summary>
    /// <value>The rate value.</value>
    public int RateValue
    {
      get { return this.rateValue; }
      internal set { this.rateValue = value; }
    }

    #endregion

  }
}
